@@ -29,17 +29,23 @@ INCLUDE_TEST_DATA="yes"
 
 BASEDIR=$(dirname $3)
 FILENAME=${BASEDIR}/${PIPELINE}-kit-${VERSION}.tar.gz
+if [ ! -f ${FILENAME} ] ; then
+  FILENAME=${BASEDIR}/${PIPELINE}-kit-${VERSION}-*.tar.gz
+  UVERSION=$(echo ${FILENAME} | sed "s/.*-kit-\(.*\)\.tar.gz/\1/")
+else
+  UVERSION=${VERSION}
+fi
 tar xf ${FILENAME} -C ${BASEDIR}
-rm -f ${BASEDIR}/${DEBIAN_PACKAGE}_${VERSION}.orig*.tar.* ${FILENAME}
+rm -f ${BASEDIR}/${DEBIAN_PACKAGE}_${UVERSION}.orig*.tar.* ${FILENAME}
 
 TAREXCLUDE="--exclude ${PIPELINE}-${VERSION}/html --exclude ${PIPELINE}-${VERSION}/libqfits"
 if [ $INCLUDE_TEST_DATA = "no" ] ; then
   TAREXCLUDE=${TAREXCLUDE}" --exclude ${PIPELINE}-${VERSION}/*/tests/ref_data"
 fi
 
-tar xf ${BASEDIR}/${PIPELINE}-kit-${VERSION}/${PIPELINE}-${VERSION}.tar.gz\
+tar xf ${BASEDIR}/${PIPELINE}-kit-${UVERSION}/${PIPELINE}-${VERSION}.tar.gz\
     -C ${BASEDIR} ${TAREXCLUDE}
-tar xf ${BASEDIR}/${PIPELINE}-kit-${VERSION}/${PIPELINE}-calib-${VERSION}.tar.gz\
+tar xf ${BASEDIR}/${PIPELINE}-kit-${UVERSION}/${PIPELINE}-calib-${VERSION}.tar.gz\
     -C ${BASEDIR}/${PIPELINE}-${VERSION}/
 mv ${BASEDIR}/${PIPELINE}-${VERSION}/${PIPELINE}-calib-${VERSION}/ \
    ${BASEDIR}/${PIPELINE}-${VERSION}/calib/
@@ -53,5 +59,5 @@ tar cJf ${BASEDIR}/${DEBIAN_PACKAGE}_${VERSION}+dfsg.orig.tar.xz \
     -C ${BASEDIR} ${PIPELINE}-${VERSION}/
 rm -rf ${BASEDIR}/${PIPELINE}-${VERSION}/
 
-rm -rf ${BASEDIR}/${PIPELINE}-kit-${VERSION}/ 
+rm -rf ${BASEDIR}/${PIPELINE}-kit-${UVERSION}/ 
 exec uupdate --no-symlink "$@"
